<?php
require_once(dirname(__FILE__) . '/../dashlet-helper.inc.php');

dashlets_data_check();

host_health_dashlet();

function host_health_dashlet() {

    $id = 'host_health_' . random_string(6);

    $categories = '';
    $up = '';
    $down = '';
    $unreachable = '';
    $problems = '';
    $unhandled = '';

    $servers = get_servers();
    foreach ($servers as $server) {

        // We currently have nothing to show here for NLS or NNA, so don't show it
        if (in_array($server['server_type'], array(SERVER_TYPE_NLS, SERVER_TYPE_NNA))) {
            continue;
        }

        $data = get_server_data($server);

        if (!$data)
            continue;
        
        $categories .= json_encode($server['name']) . ',';

        $up .= $data['hosts_up'] . ',';
        $down .= $data['hosts_down'] . ',';
        $unreachable .= $data['hosts_unreachable'] . ',';
        $problems .= $data['hosts_problems'] . ',';
        $unhandled .= $data['hosts_problems_unhandled'] . ',';
    }

    $categories = rtrim($categories, ',');
    $up = rtrim($up, ',');
    $down = rtrim($down, ',');
    $unreachable = rtrim($unreachable, ',');
    $problems = rtrim($problems, ',');
    $unhandled = rtrim($unhandled, ',');

    ?>
        <div id="<?php echo $id; ?>">
        </div>
        <script type="text/javascript">
        $(function () {
            function get_<?php echo $id; ?>_content() {

                Highcharts.setOptions({
                    colors: [ '#b2ff5f', '#FF795F', '#FEFF5F','#fed56b', '#FFE4AF' ] 
                });

                var chart = new Highcharts.Chart({
                    chart: {
                        renderTo: '<?php echo $id; ?>',
                        type: 'column',
                        backgroundColor: $('html').css('background-color'),
                    },
                    credits: {
                        enabled: false
                    },
                    title: {
                        text: '<?php echo _('Host Health Summary by Nagios Server'); ?>',
                        style: {
                            color: $('html').css('color')
                        }
                    },
                    xAxis: {
                        categories: [<?php echo $categories; ?>],
                        labels: {
                            formatter () {
                                return `<span style="color: `+ $('html').css('color') +`">${this.value}</span>`
                            }
                        }
                    },
                    yAxis: {
                        allowDecimals: false,
                        min: 0,
                        
                        title: {
                            text: '<?php echo _('Counts by state'); ?>',
                            style: {
                                color: $('html').css('color')
                            }
                        },
                        
                        labels: {
                            formatter () {
                                return `<span style="color: `+ $('html').css('color') +`">${this.value}</span>`
                            }
                        }
                    },
                    tooltip: {
                        formatter: function() {
                            return '<b>' + this.x + '</b><br/>'+
                                this.series.name +': '+ this.y +'<br/>'+
                                '<?php echo _('Total'); ?>: '+ this.point.stackTotal;
                        }
                    },
                    plotOptions: {
                        column: {
                            stacking: 'normal'
                        }
                    },
                    legend: {
                        itemStyle: {
                            font: '9pt Trebuchet MS, Verdana, sans-serif',
                            color: $('html').css('color')

                        },
                        itemHoverStyle: {
                            color: '#b8b9ba'
                        },
                        itemHiddenStyle: {
                            color: 'gray'
                        }
                    }, 
                    series: [
            			{
            	            name: '<?php echo _('Up'); ?>',
            	            data: [<?php echo $up; ?>],
            	            stack: 'state'
            	        },
            	        {
            	            name: '<?php echo _('Down'); ?>',
            	            data: [<?php echo $down; ?>],
            	            stack: 'state'
            	        },
            	        {
            	            name: '<?php echo _('Unreachable'); ?>',
            	            data: [<?php echo $unreachable; ?>],
            	            stack: 'state'
            	        },
            	        {
            	            name: '<?php echo _('Problems'); ?>',
            	            data: [<?php echo $problems; ?>],
            	            stack: 'pseudo'
            	        },
            	        {
            	            name: '<?php echo _('Unhandled'); ?>',
            	            data: [<?php echo $unhandled; ?>],
            	            stack: 'pseudo'
            	        }
                    ],
                    exporting: {
                        enabled: true,
                        buttons: {
                            contextButton: {
                                symbolStroke: '#fff',
                                theme: {
                                    fill: $('html').css('background-color'),
                                    stroke: $('html').css('background-color'),
                                }
                            }
                        }
                    }
                });
            }

            $('#<?php echo $id; ?>').closest('.ui-resizable').on('resizestop', function() {
                get_<?php echo $id; ?>_content();
            });

            get_<?php echo $id; ?>_content();
        }); 
        </script>
    <?php
}
